@@ -1,4 +1,5 @@
 import logging
+import re
 
 from django.http import JsonResponse, Http404
 
@@ -67,10 +68,11 @@ def event_feedback_internal(data, region, language, comment, rating, is_technica
     :return: JSON object according to APIv3 single page feedback endpoint definition
     :rtype: ~django.http.JsonResponse
     """
-    event_translation_slug = data.get("slug")
+    # Remove date from the slug for recurrung events
+    event_translation_slug = re.sub(r"\$\d{4}-\d{2}-\d{2}$", "", data.get("slug"))
 
     events = region.events.filter(
-        translations__slug=data.get("slug"),
+        translations__slug=event_translation_slug,
         translations__language=language,
     ).distinct()
 
@@ -81,10 +83,22 @@ def event_feedback_internal(data, region, language, comment, rating, is_technica
             events,
         )
         return JsonResponse({"error": "Internal Server Error"}, status=500)
-    if len(events) == 0:
-        raise Http404("No matching event found for slug.")
-    event = events[0]
-    event_translation = event.get_translation(language.slug)
+
+    event = None
+    if len(events) == 1:
+        event = events[0]
+    elif region.fallback_translations_enabled:
+        event = region.events.filter(
+            translations__slug=data.get("slug"),
+            translations__language=region.default_language,
+        ).first()
+
+    if not event:
+        raise Http404("No matching location found for slug.")
+
+    event_translation = event.get_translation(language.slug) or event.get_translation(
+        region.default_language.slug
+    )
 
     EventFeedback.objects.create(
         event_translation=event_translation,
