@@ -20,10 +20,16 @@ class ContentQuerySet(models.QuerySet):
     This queryset provides the option to prefetch translations for content objects
     """
 
-    def prefetch_translations(self):
-        """
-        Get the queryset including the custom attribute ``prefetched_translations`` which contains the latest
-        translations of each content object in each language
+    def prefetch_translations(self, to_attr="prefetched_translations", **filters):
+        r"""
+        Get the queryset including the custom attribute ``to_attr`` which contains the latest
+        translations of each content object in each language, optionally filtered by the given ``status``
+
+        :param to_attr: To which attribute the prefetched translations should be added [optional, defaults to ``prefetched_translations``]
+        :type to_attr: str
+
+        :param \**filters: Additional filters to be applied on the translations (e.g. by status)
+        :type \**filters: dict
 
         :return: The queryset of content objects
         :rtype: ~django.db.models.query.QuerySet [ ~integreat_cms.cms.models.abstract_content_model.AbstractContentModel ]
@@ -33,12 +39,11 @@ class ContentQuerySet(models.QuerySet):
         return self.prefetch_related(
             models.Prefetch(
                 "translations",
-                queryset=TranslationModel.objects.order_by(
-                    foreign_field, "language_id", "-version"
-                )
+                queryset=TranslationModel.objects.filter(**filters)
+                .order_by(foreign_field, "language_id", "-version")
                 .distinct(foreign_field, "language_id")
                 .select_related("language"),
-                to_attr="prefetched_translations",
+                to_attr=to_attr,
             )
         )
 
@@ -50,17 +55,21 @@ class ContentQuerySet(models.QuerySet):
         :return: The queryset of content objects
         :rtype: ~django.db.models.query.QuerySet [ ~integreat_cms.cms.models.abstract_content_model.AbstractContentModel ]
         """
-        TranslationModel = self.model.get_translation_model()
-        foreign_field = TranslationModel.foreign_field() + "_id"
-        return self.prefetch_related(
-            models.Prefetch(
-                "translations",
-                queryset=TranslationModel.objects.filter(status=status.PUBLIC)
-                .order_by(foreign_field, "language_id", "-version")
-                .distinct(foreign_field, "language_id")
-                .select_related("language"),
-                to_attr="prefetched_public_translations",
-            )
+        return self.prefetch_translations(
+            to_attr="prefetched_public_translations", status=status.PUBLIC
+        )
+
+    def prefetch_public_or_draft_translations(self):
+        """
+        Get the queryset including the custom attribute ``prefetched_public_or_draft_translations`` which contains the latest
+        public or draft translations of each content object in each language
+
+        :return: The queryset of content objects
+        :rtype: ~django.db.models.query.QuerySet [ ~integreat_cms.cms.models.abstract_content_model.AbstractContentModel ]
+        """
+        return self.prefetch_translations(
+            to_attr="prefetched_public_or_draft_translations",
+            status__in=[status.DRAFT, status.PUBLIC],
         )
 
     def prefetch_major_public_translations(self):
@@ -71,20 +80,10 @@ class ContentQuerySet(models.QuerySet):
         :return: The queryset of content objects
         :rtype: ~django.db.models.query.QuerySet [ ~integreat_cms.cms.models.abstract_content_model.AbstractContentModel ]
         """
-        TranslationModel = self.model.get_translation_model()
-        foreign_field = TranslationModel.foreign_field() + "_id"
-        return self.prefetch_related(
-            models.Prefetch(
-                "translations",
-                queryset=TranslationModel.objects.filter(
-                    status=status.PUBLIC,
-                    minor_edit=False,
-                )
-                .order_by(foreign_field, "language_id", "-version")
-                .distinct(foreign_field, "language_id")
-                .select_related("language"),
-                to_attr="prefetched_major_public_translations",
-            )
+        return self.prefetch_translations(
+            to_attr="prefetched_major_public_translations",
+            status=status.PUBLIC,
+            minor_edit=False,
         )
 
 
@@ -94,9 +93,7 @@ class AbstractContentModel(AbstractBaseModel):
     """
 
     region = models.ForeignKey(
-        Region,
-        on_delete=models.CASCADE,
-        verbose_name=_("region"),
+        Region, on_delete=models.CASCADE, verbose_name=_("region")
     )
     created_date = models.DateTimeField(
         default=timezone.now, verbose_name=_("creation date")
@@ -129,7 +126,7 @@ class AbstractContentModel(AbstractBaseModel):
         """
         # Check if fallback translation should be used
         if self.fallback_translations_enabled:
-            all_languages = self.region.active_languages
+            all_languages = self.region.visible_languages
         else:
             all_languages = self.public_languages
 
@@ -142,13 +139,49 @@ class AbstractContentModel(AbstractBaseModel):
     def public_languages(self):
         """
         This property returns a list of all :class:`~integreat_cms.cms.models.languages.language.Language` objects, to
-        which a translation exists.
+        which a public translation exists and which are visible in this region.
 
         :return: The existing languages of this content object
         :rtype: list
         """
         translations = self.prefetched_public_translations_by_language_slug.values()
-        return [translation.language for translation in translations]
+        return [
+            translation.language
+            for translation in translations
+            if translation.language in self.region.visible_languages
+        ]
+
+    def get_prefetched_translations_by_language_slug(
+        self, attr="prefetched_translations", **filters
+    ):
+        r"""
+        This method returns a mapping from language slugs to their latest translations of this object
+
+        :param attr: Which attribute should be tried to get the prefetched translations [optional, defaults to ``"prefetched_translations"``]
+        :type attr: str
+
+        :param \**filters: Additional filters to be applied on the translations (e.g. by status)
+        :type \**filters: dict
+
+        :return: The prefetched translations by language slug
+        :rtype: dict
+        """
+        try:
+            # Try to get the prefetched translations (which are already distinct per language)
+            prefetched_translations = getattr(self, attr)
+        except AttributeError:
+            # If the translations were not prefetched, query it from the database
+            prefetched_translations = (
+                self.translations.filter(**filters)
+                .select_related("language")
+                .order_by("language__id", "-version")
+                .distinct("language__id")
+                .all()
+            )
+        return {
+            translation.language.slug: translation
+            for translation in prefetched_translations
+        }
 
     @cached_property
     def prefetched_translations_by_language_slug(self):
@@ -158,21 +191,7 @@ class AbstractContentModel(AbstractBaseModel):
         :return: The prefetched translations by language slug
         :rtype: dict
         """
-        try:
-            # Try to get the prefetched translations (which are already distinct per language)
-            prefetched_translations = self.prefetched_translations
-        except AttributeError:
-            # If the translations were not prefetched, query it from the database
-            prefetched_translations = (
-                self.translations.select_related("language")
-                .order_by("language__id", "-version")
-                .distinct("language__id")
-                .all()
-            )
-        return {
-            translation.language.slug: translation
-            for translation in prefetched_translations
-        }
+        return self.get_prefetched_translations_by_language_slug()
 
     def get_translation(self, language_slug):
         """
@@ -197,21 +216,9 @@ class AbstractContentModel(AbstractBaseModel):
                  :obj:`None` if no translation exists
         :rtype: dict
         """
-        try:
-            # Try to get the prefetched translations (which are already distinct per language)
-            prefetched_public_translations = self.prefetched_public_translations
-        except AttributeError:
-            # If the translations were not prefetched, query it from the database
-            prefetched_public_translations = (
-                self.translations.filter(status=status.PUBLIC)
-                .select_related("language")
-                .order_by("language__id", "-version")
-                .distinct("language__id")
-            )
-        return {
-            translation.language.slug: translation
-            for translation in prefetched_public_translations
-        }
+        return self.get_prefetched_translations_by_language_slug(
+            attr="prefetched_public_translations", status=status.PUBLIC
+        )
 
     def get_public_translation(self, language_slug):
         """
@@ -254,6 +261,35 @@ class AbstractContentModel(AbstractBaseModel):
                     pass
         return public_translation
 
+    @cached_property
+    def prefetched_public_or_draft_translations_by_language_slug(self):
+        """
+        This method returns a mapping from language slugs to their public translations of this object
+
+        :return: The object translation in the requested :class:`~integreat_cms.cms.models.languages.language.Language` or
+                 :obj:`None` if no translation exists
+        :rtype: dict
+        """
+        return self.get_prefetched_translations_by_language_slug(
+            attr="prefetched_public_or_draft_translations",
+            status__in=[status.DRAFT, status.PUBLIC],
+        )
+
+    def get_public_or_draft_translation(self, language_slug):
+        """
+        This function retrieves the newest public or draft translation of a content object.
+
+        :param language_slug: The slug of the requested :class:`~integreat_cms.cms.models.languages.language.Language`
+        :type language_slug: str
+
+        :return: The public translation of a content object
+        :rtype: ~integreat_cms.cms.models.abstract_content_translation.AbstractContentTranslation
+        """
+        translation = self.prefetched_public_or_draft_translations_by_language_slug.get(
+            language_slug
+        )
+        return translation
+
     @cached_property
     def prefetched_major_public_translations_by_language_slug(self):
         """
@@ -263,21 +299,11 @@ class AbstractContentModel(AbstractBaseModel):
                  :obj:`None` if no translation exists
         :rtype: dict
         """
-        try:
-            # Try to get the prefetched translations (which are already distinct per language)
-            prefetched_public_translations = self.prefetched_major_public_translations
-        except AttributeError:
-            # If the translations were not prefetched, query it from the database
-            prefetched_public_translations = (
-                self.translations.filter(status=status.PUBLIC, minor_edit=False)
-                .select_related("language")
-                .order_by("language__id", "-version")
-                .distinct("language__id")
-            )
-        return {
-            translation.language.slug: translation
-            for translation in prefetched_public_translations
-        }
+        return self.get_prefetched_translations_by_language_slug(
+            attr="prefetched_major_public_translations",
+            status=status.PUBLIC,
+            minor_edit=False,
+        )
 
     def get_major_public_translation(self, language_slug):
         """
